=========================
scikit-nano documentation
=========================

:Release: |release|
:Date: |today|

.. toctree::
   :maxdepth: 2

   getting_started.rst

.. toctree::
   :maxdepth: 2

   tutorial/index.rst

.. toctree::
   :maxdepth: 1

   contribute.rst
   release.rst
   credits.rst

Reference
=========

.. toctree::
   :maxdepth: 1

   chemistry.rst
   nanogen.rst
   scripts.rst
   structure_io.rst

pykit projects
---------------
    * `pykit-sci docs`_
    * `pykit-shared docs`_


* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

.. _pykit-sci docs: http://projects.geekspin.net/pykit-sci/doc
.. _pykit-shared docs: http://projects.geekspin.net/pykit-shared/doc
